﻿using System;
using System.Collections.Generic;

namespace EGRemoteStudio
{
    public class DeviceList : List<Device>
    {
        // A delegate type for hooking up change notifications.
        public delegate void ChangedEventHandler(object sender, DeviceListChangedArgs e);
        public event ChangedEventHandler DeviceListChanged;

        public class DeviceListChangedArgs : EventArgs
        {
            public List<Device> deviceList;

            public DeviceListChangedArgs(List<Device> deviceList)
            {
                this.deviceList = deviceList;
            }
        }
        
        public new void Add(Device device)
        {
            base.Add(device);

            if (DeviceListChanged != null)
                DeviceListChanged(this, new DeviceListChangedArgs(this));
        }
        
        public new void Remove(Device device)
        {
            base.Remove(device);

            if (DeviceListChanged != null)
                DeviceListChanged(this, new DeviceListChangedArgs(this));
        }

        public new void RemoveAll(Predicate<Device> match)
        {
            base.RemoveAll(match);

            if (DeviceListChanged != null)
                DeviceListChanged(this, new DeviceListChangedArgs(this));
        }

        public new void Clear()
        {
            base.Clear();

            if (DeviceListChanged != null)
                DeviceListChanged(this, new DeviceListChangedArgs(this));
        }
    }
}
