﻿using System;
using System.Collections.Generic;
using System.IO;
using System.IO.IsolatedStorage;
using System.Linq;
using System.Text;
using Newtonsoft.Json;

namespace EGRemoteStudio
{
    public class DeviceListManager
    {
        private const string DEVICE_FILE = "registered_devices.txt";

        public List<Device> ReadDeviceListFile()
        {
            using (IsolatedStorageFile file = IsolatedStorageFile.GetStore
                (IsolatedStorageScope.User | IsolatedStorageScope.Assembly | IsolatedStorageScope.Domain, null, null))
            {
                try
                {
                    using (var reader = new JsonTextReader(new StreamReader(DEVICE_FILE)))
                    {
                        var serializer = new JsonSerializer();

                       return serializer.Deserialize<List<Device>>(reader);
                    }
                }
                catch (FileNotFoundException e)
                {
                    return new List<Device>();
                }
            }
        }

        public void WriteDeviceListFile(List<Device> deviceList)
        {
            /* first we delete the old file, afterwards we create the new one */
            DeleteFileList();

            using (IsolatedStorageFile file = IsolatedStorageFile.GetStore
                (IsolatedStorageScope.User | IsolatedStorageScope.Assembly | IsolatedStorageScope.Domain, null, null))
            {
                using (var writer = new JsonTextWriter(new StreamWriter(DEVICE_FILE)))
                {
                    var serializer = new JsonSerializer();

                    serializer.Serialize(writer, deviceList);
                }
            }
        }

        private void DeleteFileList ()
        {
            using (IsolatedStorageFile file = IsolatedStorageFile.GetStore
                (IsolatedStorageScope.User | IsolatedStorageScope.Assembly | IsolatedStorageScope.Domain, null, null))
            {
                if (file.FileExists(DEVICE_FILE))
                    file.DeleteFile(DEVICE_FILE);
            }
        }
    }
}
