﻿using System;
using System.Collections.Generic;
using System.Windows.Forms;
using EGRemoteStudio.Log;
using EGRemoteStudio.Settings;
using WeifenLuo.WinFormsUI.Docking;

namespace EGRemoteStudio.Forms
{
    public partial class MainForm : Form
    {
        private readonly DeviceHandler deviceHandler;
        private readonly DeviceListPanel deviceListPanel;
        private readonly LogPanel log;
        private readonly HelpPanel help;
        private readonly SettingsDialog settingsDialog;
        private readonly SettingsManager settingsManager;
        private readonly Settings.Settings settings;

        public MainForm()
        {
            InitializeComponent();

            settingsManager = new SettingsManager();
            settings = settingsManager.ReadSettingsFile();

            dockPanel.SuspendLayout(true);

            try
            {
                deviceHandler = new DeviceHandler();
                deviceHandler.DeviceList.DeviceListChanged += deviceHandler_DeviceListChanged;
                deviceHandler.OnNetworkEvent += deviceHandler_OnNetworkEvent;
                deviceHandler.OnListenEvent += deviceHandler_OnListenEvent;
                deviceHandler.RestoreDevices();
                deviceHandler.StartListener(settings.Port);

                if (System.Deployment.Application.ApplicationDeployment.IsNetworkDeployed)
                {
                    System.Deployment.Application.ApplicationDeployment ad =
                    System.Deployment.Application.ApplicationDeployment.CurrentDeployment;
                    ts_label_version.Text = "v" + ad.CurrentVersion;
                }
            }
            catch (Exception)
            {
                MessageBox.Show(this, "A network problem has been detected, is the application already running?", "Network error occured", MessageBoxButtons.OK, MessageBoxIcon.Warning);
            }
            
        }

        void deviceHandler_OnListenEvent(object sender, DeviceHandler.ListenEventArgs e)
        {
            ts_label_port.Text = "Listening for new devices on port " + e.Port + " ...";
        }

        /// <summary> Handles the OnNetworkEvent event of the deviceHandler control. </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="NetworkEventreceiver.NetworkEventArgs" /> instance containing the event data.</param>
        /// <exception cref="System.NotImplementedException"></exception>
        private void deviceHandler_OnNetworkEvent(object sender, NetworkEventreceiver.NetworkEventArgs e)
        {
            log.AddLogMessage(new LogMessage(e.device, e.ntwEvent, e.ntwPayload));
        }

        void deviceListPanel_DeviceListClear(object sender, EventArgs e)
        {
            deviceHandler.DeviceList.Clear();
        }

        void deviceHandler_DeviceListChanged(object sender, DeviceList.DeviceListChangedArgs e)
        {
            UpdateDeviceList(e.deviceList);
        }

        private void UpdateDeviceList(List<Device> deviceList)
        {
            deviceListPanel.UpdateList(deviceList);
            /* TODO: update complete list, remove is not supported at the moment */
        }
                    
        private void MainForm_Resize(object sender, EventArgs e)
        {
            if (WindowState == FormWindowState.Minimized)
            {
                trayIcon.Visible = true;
                trayIcon.ShowBalloonTip(500);
                Hide();
            }
            //else if (this.WindowState == FormWindowState.Normal)
                //trayIcon.Visible = false;
        }

        private void notifyIcon1_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            Show();
            WindowState = FormWindowState.Normal;
        }

        private void trayToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            Show();
            WindowState = FormWindowState.Normal;
        }

        private void trayToolStripMenuItem2_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void toolStripButton1_Click(object sender, EventArgs e)
        {
            int old_port = settings.Port;
            settingsDialog.ShowDialog(this);
            settingsManager.WriteDeviceListFile(settings);
            if (old_port != settings.Port)
            {
                deviceHandler.StopListener();
                deviceHandler.StartListener(settings.Port);
            }
        }
    }
}
