﻿using System.IO;
using System.IO.IsolatedStorage;
using Newtonsoft.Json;

namespace EGRemoteStudio.Settings
{
    public class SettingsManager
    {
        private const string SETTINGS_FILE = "settings.txt";

        public Settings ReadSettingsFile()
        {
            using (IsolatedStorageFile file = IsolatedStorageFile.GetStore
                (IsolatedStorageScope.User | IsolatedStorageScope.Assembly | IsolatedStorageScope.Domain, null, null))
            {
                try
                {
                    using (var reader = new JsonTextReader(new StreamReader(SETTINGS_FILE)))
                    {
                        var serializer = new JsonSerializer();

                       return serializer.Deserialize<Settings>(reader);
                    }
                }
                catch (FileNotFoundException e)
                {
                    return new Settings();
                }
            }
        }

        public void WriteDeviceListFile(Settings settings)
        {
            /* first we delete the old file, afterwards we create the new one */
            DeleteFileList();

            using (IsolatedStorageFile file = IsolatedStorageFile.GetStore
                (IsolatedStorageScope.User | IsolatedStorageScope.Assembly | IsolatedStorageScope.Domain, null, null))
            {
                using (var writer = new JsonTextWriter(new StreamWriter(SETTINGS_FILE)))
                {
                    var serializer = new JsonSerializer();

                    serializer.Serialize(writer, settings);
                }
            }
        }

        private void DeleteFileList ()
        {
            using (IsolatedStorageFile file = IsolatedStorageFile.GetStore
                (IsolatedStorageScope.User | IsolatedStorageScope.Assembly | IsolatedStorageScope.Domain, null, null))
            {
                if (file.FileExists(SETTINGS_FILE))
                    file.DeleteFile(SETTINGS_FILE);
            }
        }
    }
}